# Group_1

**Installation**

`$pip install Group_1`

**Installing the requirements**

`pip install -r requirements_dev.txt`

**Importing the library**

`from Group_1.cluster import "name of the algorithm"`

